Description: Add shebang to python script
Author: Paschalis Melissas
Origin: upstream
Applied-Upstream: https://github.com/grame-cncm/faust/commit/bbf44bcc16b093615a86771309ab5a79d366fcd0
Last-Update: 2025-10-02
---
This patch header follows DEP-3: http://dep.debian.net/deps/dep3/
--- faust.orig/tools/faust2appls/faust2wwise.py
+++ faust/tools/faust2appls/faust2wwise.py
@@ -180,4 +180,4 @@
 
             print("Exiting faust2wwise with error code 1 : Missing or inaccessible environment variables or system calls.")
             print_message_on_fail()
-            sys.exit(1)
\ No newline at end of file
+            sys.exit(1)
